==> git-4.3.7.tar.gz: git-4.3.7/acconfig.h <==
/* Define if you have BSD compatible terminal interface.  */
#undef HAVE_BSDTTY

/* Define if you have GCC.  */
#undef HAVE_GCC

/* Define if your system is HP-UX.  */
#undef HAVE_HPUX

/* Define if you have a termcap library.  */
#undef HAVE_LIBTERMCAP

/* Define if you have a terminfo library.  */
#undef HAVE_LIBTERMINFO

/* Define if your system is Linux.  */
#undef HAVE_LINUX

/* Define if you have POSIX compatible terminal interface.  */
#undef HAVE_POSIXTTY

/* Define if you have System V compatible terminal interface.  */
#undef HAVE_SYSTEMVTTY

/* Define if you have the utsname system call.  */
#undef HAVE_UTSNAME

/* Define if you have the TIOCGWINSZ ioctl system call.  */
#undef HAVE_WINSZ

/* Define if you have two-argument statfs with statfs.bsize member
   (AIX, 4.3BSD).  */
#undef STAT_STATFS2_BSIZE

/* Define if you have two-argument statfs with statfs.fsize member
   (4.4BSD and NetBSD).  */
#undef STAT_STATFS2_FSIZE

/* Define if you have two-argument statfs with struct fs_data (Ultrix).  */
#undef STAT_STATFS2_FS_DATA

/* Define if you have 3-argument statfs function (DEC OSF/1).  */
#undef STAT_STATFS3_OSF1

/* Define if you have four-argument statfs (AIX-3.2.5, SVR3).  */
#undef STAT_STATFS4

/* Define if you have the statvfs system call.  */
#undef STAT_STATVFS


/* Leave that blank line there!!  Autoheader needs it.
   If you're adding to this file, keep in mind:
   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  */

==> git-4.3.17.tar.gz: git-4.3.17/acconfig.h <==
/* $Id: acconfig.h,v 1.2 1998/03/02 08:33:14 tudor Exp $ */

/* Define if you have GCC.  */
#undef HAVE_GCC

/* Define if you have a termcap library.  */
#undef HAVE_LIBTERMCAP

/* Define if you have a terminfo library.  */
#undef HAVE_LIBTERMINFO

/* Define if your system is Linux.  */
#undef HAVE_LINUX

/* Define if you have a dumb C compiler, like the one running on B.O.S.  */
#undef HAVE_DUMB_CC

/* Define if you have POSIX compatible terminal interface.  */
#undef HAVE_POSIX_TTY

/* Define if you have System V compatible terminal interface.  */
#undef HAVE_SYSTEMV_TTY

/* Define if you have BSD compatible terminal interface.  */
#undef HAVE_BSD_TTY

/* Define if you have the utsname system call.  */
#undef HAVE_UTSNAME

/* Define if you have the TIOCGWINSZ ioctl system call.  */
#undef HAVE_WINSZ

/* Define if you have two-argument statfs with statfs.bsize member
   (AIX, 4.3BSD).  */
#undef STAT_STATFS2_BSIZE

/* Define if you have two-argument statfs with statfs.fsize member
   (4.4BSD and NetBSD).  */
#undef STAT_STATFS2_FSIZE

/* Define if you have two-argument statfs with struct fs_data (Ultrix).  */
#undef STAT_STATFS2_FS_DATA

/* Define if you have 3-argument statfs function (DEC OSF/1).  */
#undef STAT_STATFS3_OSF1

/* Define if you have four-argument statfs (AIX-3.2.5, SVR3).  */
#undef STAT_STATFS4

/* Define if you have the statvfs system call.  */
#undef STAT_STATVFS


/* Leave that blank line there!!  Autoheader needs it.
   If you're adding to this file, keep in mind:
   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  */
